@@ -85,8 +85,8 @@ class Testing(unittest.TestCase):
             """import uvicorn
 from fastapi import FastAPI
 
-from fastapi_quick_crud_template.route.test_build_myself_memory import api as test_build_myself_memory_router
-from fastapi_quick_crud_template.route.test_build_myself_memory_two import api as test_build_myself_memory_two_router
+from route.test_build_myself_memory import api as test_build_myself_memory_router
+from route.test_build_myself_memory_two import api as test_build_myself_memory_two_router
 app = FastAPI()
 
 [app.include_router(api_route) for api_route in [
@@ -106,8 +106,8 @@ from sqlalchemy.ext.asyncio import create_async_engine, AsyncSession
 from sqlalchemy.orm import declarative_base, sessionmaker
 from sqlalchemy.pool import StaticPool
 
-from fastapi_quick_crud_template.model.test_build_myself_memory import SampleTable
-from fastapi_quick_crud_template.model.test_build_myself_memory_two import SampleTableTwo
+from model.test_build_myself_memory import SampleTable
+from model.test_build_myself_memory_two import SampleTableTwo
 
 SQLALCHEMY_DATABASE_URL = f"sqlite+aiosqlite://"
 
@@ -151,9 +151,9 @@ from pydantic import BaseModel
 from fastapi import Body, Query
 from sqlalchemy import *
 from sqlalchemy.dialects.sqlite import *
-from fastapi_quick_crud_template.common.utils import ExcludeUnsetBaseModel, filter_none, value_of_list_to_str
-from fastapi_quick_crud_template.common.db import Base
-from fastapi_quick_crud_template.common.typing import ExtraFieldTypePrefix, ItemComparisonOperators, MatchingPatternInStringBase, PGSQLMatchingPatternInString, RangeFromComparisonOperators, RangeToComparisonOperators
+from common.utils import ExcludeUnsetBaseModel, filter_none, value_of_list_to_str
+from common.db import Base
+from common.typing import ExtraFieldTypePrefix, ItemComparisonOperators, MatchingPatternInStringBase, PGSQLMatchingPatternInString, RangeFromComparisonOperators, RangeToComparisonOperators
 
 PRIMARY_KEY_NAME = "primary_key"
 UNIQUE_LIST = "primary_key"
@@ -222,9 +222,9 @@ from pydantic import BaseModel
 from fastapi import Body, Query
 from sqlalchemy import *
 from sqlalchemy.dialects.sqlite import *
-from fastapi_quick_crud_template.common.utils import ExcludeUnsetBaseModel, filter_none, value_of_list_to_str
-from fastapi_quick_crud_template.common.db import Base
-from fastapi_quick_crud_template.common.typing import ExtraFieldTypePrefix, ItemComparisonOperators, MatchingPatternInStringBase, PGSQLMatchingPatternInString, RangeFromComparisonOperators, RangeToComparisonOperators
+from common.utils import ExcludeUnsetBaseModel, filter_none, value_of_list_to_str
+from common.db import Base
+from common.typing import ExtraFieldTypePrefix, ItemComparisonOperators, MatchingPatternInStringBase, PGSQLMatchingPatternInString, RangeFromComparisonOperators, RangeToComparisonOperators
 
 PRIMARY_KEY_NAME = "primary_key"
 UNIQUE_LIST = "primary_key", "int4_value", "float4_value"
@@ -401,11 +401,11 @@ from typing import List, Union
 from sqlalchemy import and_, select
 from fastapi import APIRouter, Depends, Response
 from sqlalchemy.sql.elements import BinaryExpression
-from fastapi_quick_crud_template.common.utils import find_query_builder
-from fastapi_quick_crud_template.common.sql_session import db_session
+from common.utils import find_query_builder
+from common.sql_session import db_session
 from sqlalchemy.exc import IntegrityError
 from pydantic import parse_obj_as
-from fastapi_quick_crud_template.model.test_build_myself_memory_two import SampleTableTwo, SampleTableTwoPatchOneRequestBodyModel, SampleTableTwoPatchOneRequestQueryModel, SampleTableTwoPatchOneResponseModel, SampleTableTwoPrimaryKeyModel
+from model.test_build_myself_memory_two import SampleTableTwo, SampleTableTwoPatchOneRequestBodyModel, SampleTableTwoPatchOneRequestQueryModel, SampleTableTwoPatchOneResponseModel, SampleTableTwoPrimaryKeyModel
 
 api = APIRouter(tags=['sample api'],prefix="/my_second_api")
 
@@ -456,11 +456,11 @@ from typing import List, Union
 from sqlalchemy import and_, select
 from fastapi import APIRouter, Depends, Response
 from sqlalchemy.sql.elements import BinaryExpression
-from fastapi_quick_crud_template.common.utils import find_query_builder
-from fastapi_quick_crud_template.common.sql_session import db_session
+from common.utils import find_query_builder
+from common.sql_session import db_session
 from sqlalchemy.exc import IntegrityError
 from pydantic import parse_obj_as
-from fastapi_quick_crud_template.model.test_build_myself_memory import SampleTable, SampleTablePatchOneRequestBodyModel, SampleTablePatchOneRequestQueryModel, SampleTablePatchOneResponseModel, SampleTablePrimaryKeyModel
+from model.test_build_myself_memory import SampleTable, SampleTablePatchOneRequestBodyModel, SampleTablePatchOneRequestQueryModel, SampleTablePatchOneResponseModel, SampleTablePrimaryKeyModel
 
 api = APIRouter(tags=['sample api'],prefix="/my_first_api")
 
